@@ -28,7 +28,6 @@
 G_BEGIN_DECLS
 
 #include <oobs/oobs.h>
-#include <gconf/gconf-client.h>
 
 typedef struct _GstTool      GstTool;
 typedef struct _GstToolClass GstToolClass;
@@ -48,11 +47,10 @@ struct _GstTool {
 	gchar *name;
 	gchar *title;
 	gchar *icon;
-	gboolean lock_button;
+	gboolean show_lock_button;
 
 	OobsSession *session;
 	GPtrArray   *objects;
-	GConfClient *gconf_client;
 
 	char *ui_path;
 	char *common_ui_path;
@@ -118,7 +116,11 @@ void         gst_tool_commit_error    (GstTool             *tool,
 void         gst_tool_update_async    (GstTool             *tool);
 
 void         gst_tool_add_configuration_object (GstTool    *tool,
-						OobsObject *object);
+                                                OobsObject *object,
+                                                gboolean    watch_updates);
+
+gboolean     gst_tool_authenticate    (GstTool *tool,
+				       OobsObject *object);
 
 
 G_END_DECLS
