@@ -20,7 +20,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gdk/gdkpixbuf.h>
+#include <gdk/gdk.h>
 #include "gst.h"
 #include "callbacks.h"
 #include "ifaces-list.h"
@@ -258,7 +258,7 @@ get_iface_pixbuf (OobsIface *iface)
   /* fallback to a "generic" icon */
   if (!pixbuf)
     pixbuf = gtk_icon_theme_load_icon (gst_tool_get_icon_theme (tool),
-				       "gnome-fs-network", 48, 0, NULL);
+				       "preferences-system-network", 48, 0, NULL);
   return pixbuf;
 }
 
@@ -292,23 +292,51 @@ get_iface_secondary_text (OobsIface *iface)
       config_method = oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface));
 
       if (config_method && strcmp (config_method, "static") == 0)
-	g_string_append_printf (str, _("<b>Address:</b> %s <b>Subnet mask:</b> %s"),
+	g_string_append_printf (str, "<b>%s</b> %s <b>%s</b> %s",
+				_("Address:"),
 				oobs_iface_ethernet_get_ip_address (OOBS_IFACE_ETHERNET (iface)),
+				 _("Subnet mask:"),
 				oobs_iface_ethernet_get_network_mask (OOBS_IFACE_ETHERNET (iface)));
       else
-	g_string_append_printf (str, _("<b>Address:</b> %s"), config_method);
+	g_string_append_printf (str, "<b>%s</b> %s", _("Address:"), config_method);
     }
   else if (OOBS_IS_IFACE_PLIP (iface))
     {
-      g_string_append_printf (str, _("<b>Address:</b> %s <b>Remote address:</b> %s"),
+      g_string_append_printf (str, "<b>%s</b> %s <b>%s</b> %s",
+			      _("Address:"),
 			      oobs_iface_plip_get_address (OOBS_IFACE_PLIP (iface)),
+			      _("Remote address:"),
 			      oobs_iface_plip_get_remote_address (OOBS_IFACE_PLIP (iface)));
     }
   else if (OOBS_IS_IFACE_PPP (iface))
     {
-      g_string_append_printf (str, _("<b>Phone number:</b> %s <b>Login:</b> %s"),
-			      oobs_iface_ppp_get_phone_number (OOBS_IFACE_PPP (iface)),
-			      oobs_iface_ppp_get_login (OOBS_IFACE_PPP (iface)));
+      const gchar *type;
+
+      type = oobs_iface_ppp_get_connection_type (OOBS_IFACE_PPP (iface));
+
+      if (strcmp (type, "modem") == 0 ||
+	  strcmp (type, "isdn") == 0)
+	g_string_append_printf (str,"<b>%s</b> %s <b>%s</b> %s",
+				_("Type:"), type,
+				_("Phone number:"),
+				oobs_iface_ppp_get_phone_number (OOBS_IFACE_PPP (iface)));
+      else if (strcmp (type, "gprs") == 0)
+	g_string_append_printf (str, "<b>%s</b> %s <b>%s</b> %s",
+				_("Type:"), type,
+				_("Access point name:"),
+				oobs_iface_ppp_get_apn (OOBS_IFACE_PPP (iface)));
+      else if (strcmp (type, "pppoe") == 0)
+	{
+	  OobsIfaceEthernet *ethernet;
+
+	  ethernet = oobs_iface_ppp_get_ethernet (OOBS_IFACE_PPP (iface));
+	  g_string_append_printf (str, "<b>%s</b> %s <b>%s</b> %s",
+				  _("Type:"), type,
+				  _("Ethernet interface:"),
+				  oobs_iface_get_device_name (OOBS_IFACE (ethernet)));
+	}
+      else
+	g_string_append_printf (str, "<b>%s<b> %s", _("Type:"), type);
     }
 
   text = str->str;
