@@ -21,6 +21,8 @@
 #include <oobs/oobs.h>
 #include <string.h>
 #include <gio/gio.h>
+#include <glib.h>
+#include <glib/gstdio.h>
 #include "network-locations.h"
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -154,7 +156,7 @@ gst_network_locations_init (GstNetworkLocations *locations)
 		      G_CALLBACK (directory_monitor_changed), locations);
   else if (error)
     {
-      g_warning (error->message);
+      g_warning ("%s", error->message);
       g_error_free (error);
     }
 
@@ -486,7 +488,7 @@ get_interface_properties (OobsIface *iface)
 {
   GPtrArray *array;
   GParamSpec **params;
-  gint n_params, i;
+  guint n_params, i;
 
   params = g_object_class_list_properties (G_OBJECT_GET_CLASS (iface), &n_params);
   array = g_ptr_array_sized_new (n_params);
@@ -545,7 +547,7 @@ compare_interface (OobsIface *iface,
 {
   gboolean equal = FALSE;
   gchar *name;
-  gint i;
+  guint i;
 
   g_object_get (iface, "device", &name, NULL);
 
@@ -804,7 +806,7 @@ set_interface (OobsIface *iface,
 	       GKeyFile  *key_file)
 {
   gchar *name;
-  gint i;
+  guint i;
 
   g_object_get (iface, "device", &name, NULL);
 
@@ -921,7 +923,7 @@ concatenate_aliases (OobsStaticHost *static_host)
 
   while (elem)
     {
-      g_string_append_printf (str, ";%s", elem->data);
+      g_string_append_printf (str, ";%s", (gchar *)elem->data);
       elem = elem->next;
     }
 
@@ -1006,7 +1008,7 @@ save_interface (OobsIface *iface,
 		GKeyFile  *key_file)
 {
   gchar *name;
-  gint i;
+  guint i;
 
   g_object_get (iface, "device", &name, NULL);
 
@@ -1129,13 +1131,12 @@ gst_network_locations_save_current (GstNetworkLocations *locations,
   return result;
 }
 
-gboolean
+void
 gst_network_locations_delete_location (GstNetworkLocations *locations,
 				       const gchar         *name)
 {
   GstNetworkLocationsPrivate *priv;
   gchar *filename, *str, *location_path;
-  gboolean success;
 
   g_return_val_if_fail (GST_IS_NETWORK_LOCATIONS (locations), FALSE);
 
@@ -1148,6 +1149,4 @@ gst_network_locations_delete_location (GstNetworkLocations *locations,
   g_unlink (location_path);
   g_free (location_path);
   g_free (filename);
-
-  return success;
 }
