@@ -29,12 +29,12 @@
 
 /* WARNING: keep this array *always* in sync with src/common/gst-service-role.h enum order */
 const ServiceDescription descriptions[] = {
-	{ FALSE, "apacheconf",         N_("Web server"),                      N_("Shares your web pages over the Internet") },  /* GST_ROLE_WEB_SERVER */
+	{ FALSE, "applications-internet", N_("Web server"),                      N_("Shares your web pages over the Internet") },  /* GST_ROLE_WEB_SERVER */
 	{ FALSE, "stock_alarm",        N_("Actions scheduler"),               N_("Executes scheduled actions") },	        /* GST_ROLE_COMMAND_SCHEDULER */
-	{ FALSE, "gnome-dev-printer",  N_("Printer service"),                 N_("Allows applications to use printers") },      /* GST_ROLE_PRINTER_SERVICE */
-	{ FALSE, "stock_mail-send",    N_("Mail agent"),                      N_("Delivers your outgoing mail") },	        /* GST_ROLE_MTA */
+	{ FALSE, "printer",            N_("Printer service"),                 N_("Allows applications to use printers") },      /* GST_ROLE_PRINTER_SERVICE */
+	{ FALSE, "mail-send",          N_("Mail agent"),                      N_("Delivers your outgoing mail") },	        /* GST_ROLE_MTA */
 	{ FALSE, "stock_lock",         N_("MTA authentication service"),      NULL }, /* GST_ROLE_MTA_AUTH */
-	{ FALSE, "stock_mail-receive", N_("Mail fetcher"),                    N_("Downloads your mail from remote accounts") }, /* GST_ROLE_MAIL_FETCHER */
+	{ FALSE, "mail-receive",       N_("Mail fetcher"),                    N_("Downloads your mail from remote accounts") }, /* GST_ROLE_MAIL_FETCHER */
 	{ TRUE,  "gdm",                N_("Graphical login manager"),         N_("Allows users to login graphically") },        /* GST_ROLE_DISPLAY_MANAGER */
 	{ FALSE, "file-manager",       N_("Database server"),                 N_("Data storage system") },                      /* GST_ROLE_DATABASE_SERVER */
 	{ FALSE, "gnome-fs-smb",       N_("Folder sharing service"),          N_("Shares folders over your network") },         /* GST_ROLE_FILE_SERVER_SMB */
@@ -46,62 +46,62 @@ const ServiceDescription descriptions[] = {
 	{ FALSE, "stock_lock",         N_("Antivirus"),                       N_("Analyzes your incoming mail for virus") },    /* GST_ROLE_ANTIVIRUS */
 	{ FALSE, "stock_lock",         N_("Firewall"),                        N_("Blocks undesired network "
 										 "access to your computer") },                  /* GST_ROLE_FIREWALL_MANAGEMENT */
-	{ FALSE, NULL,                 N_("Dictionary server"),               NULL }, /* GST_ROLE_DICTIONARY_SERVER */
+	{ FALSE, "accessories-dictionary", N_("Dictionary server"),           NULL }, /* GST_ROLE_DICTIONARY_SERVER */
 	{ FALSE, "access",             N_("Speech synthesis support"),        NULL }, /* GST_ROLE_SPEECH_SYNTHESIS */
 	{ FALSE, "logviewer",          N_("Computer activity logger"),        N_("Keeps a log of your computer activity") },    /* GST_ROLE_SYSTEM_LOGGER */
 	{ FALSE, NULL,                 N_("Remote backup server"),            NULL }, /* GST_ROLE_REMOTE_BACKUP */
-	{ FALSE, "stock_spam",         N_("Spam filter"),                     NULL }, /* GST_ROLE_SPAM_FILTER */
-	{ FALSE, "gnome-terminal",     N_("Remote shell server"),             N_("Secure shell server") },                      /* GST_ROLE_SECURE_SHELL_SERVER */
+	{ FALSE, "mail-mark-junk",     N_("Spam filter"),                     NULL }, /* GST_ROLE_SPAM_FILTER */
+	{ FALSE, "utilities-terminal", N_("Remote shell server"),             N_("Secure shell server") },                      /* GST_ROLE_SECURE_SHELL_SERVER */
 	{ FALSE, "stock_script",       N_("Application server"),              NULL }, /* GST_ROLE_APPLICATION_SERVER */
 	{ FALSE, NULL,                 N_("Automated crash reports support"), NULL }, /* GST_ROLE_AUTOMATED_CRASH_REPORTS_MANAGEMENT */
 	{ TRUE,  NULL,                 N_("System communication bus"),        NULL }, /* GST_ROLE_DBUS, */
 	{ FALSE, "gtk-preferences",    N_("System configuration manager"),    NULL }, /* GST_ROLE_SYSTEM_CONFIGURATION_MANAGEMENT */
-	{ FALSE, NULL,                 N_("School management platform"),      NULL }, /* GST_ROLE_SCHOOL_MANAGEMENT_PLATFORM */
+	{ FALSE, "applications-education", N_("School management platform"),      NULL }, /* GST_ROLE_SCHOOL_MANAGEMENT_PLATFORM */
 	{ FALSE, "stock_lock",         N_("Network security auditor"),        NULL }, /* GST_ROLE_SECURITY_AUDITING */
 	{ FALSE, "stock_web-calendar", N_("Web calendar server"),             NULL }, /* GST_ROLE_WEB_CALENDAR_SERVER */
 	{ FALSE, NULL,                 N_("OEM configuration manager"),       NULL }, /* GST_ROLE_OEM_CONFIGURATION_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Terminal multiplexor"),            NULL }, /* GST_ROLE_TERMINAL_MULTIPLEXOR */
 	{ TRUE,  NULL,                 N_("Disk quota activation"),           NULL }, /* GST_ROLE_QUOTA_MANAGEMENT */
-	{ FALSE, "gnome-package",      N_("Package index monitor"),           NULL }, /* GST_ROLE_PACKAGE_INDEX_MONITORING */
-	{ TRUE,  NULL,                 N_("Network service"),                 NULL }, /* GST_ROLE_NETWORK */
+	{ FALSE, "package-x-generic",  N_("Package index monitor"),           NULL }, /* GST_ROLE_PACKAGE_INDEX_MONITORING */
+	{ TRUE,  "preferences-system-network", N_("Network service"),         NULL }, /* GST_ROLE_NETWORK */
 	{ FALSE, NULL,                 N_("Dynamic DNS services updater"),    NULL }, /* GST_ROLE_DYNAMIC_DNS_SERVICE */
 	{ FALSE, NULL,                 N_("DHCP server"),                     NULL }, /* GST_ROLE_DHCP_SERVER */
 	{ FALSE, NULL,                 N_("Domain name server"),              NULL }, /* GST_ROLE_DNS */
 	{ FALSE, NULL,                 N_("Proxy cache service"),             NULL }, /* GST_ROLE_PROXY_CACHE */
 	{ TRUE,  NULL,                 N_("LDAP server"),                     NULL }, /* GST_ROLE_LDAP_SERVER */
-	{ FALSE, NULL,                 N_("Mailing lists manager"),           NULL }, /* GST_ROLE_MAILING_LISTS_MANAGER */
+	{ FALSE, "mail-unread",        N_("Mailing lists manager"),           NULL }, /* GST_ROLE_MAILING_LISTS_MANAGER */
 	{ TRUE,  NULL,                 N_("Multicast DNS service discovery"), NULL }, /* GST_ROLE_RENDEZVOUS */
 	{ TRUE,  NULL,                 N_("Account information resolver"),    NULL }, /* GST_ROLE_NSS */
 	{ TRUE,  NULL,                 N_("Virtual Private Network server"),  NULL }, /* GST_ROLE_VPN_SERVER */
 	{ FALSE, NULL,                 N_("Router advertisement server"),     NULL }, /* GST_ROLE_ROUTER_ADVERTISEMENT_SERVER */
 	{ FALSE, NULL,                 N_("IPSec key exchange server"),       NULL }, /* GST_ROLE_IPSEC_KEY_EXCHANGE_SERVER */
-	{ FALSE, NULL,                 N_("Disk server"),                     NULL }, /* GST_ROLE_DISK_SERVER */
-	{ FALSE, NULL,                 N_("Disk client"),                     NULL }, /* GST_ROLE_DISK_CLIENT */
+	{ FALSE, "disks",              N_("Disk server"),                     NULL }, /* GST_ROLE_DISK_SERVER */
+	{ FALSE, "disks",              N_("Disk client"),                     NULL }, /* GST_ROLE_DISK_CLIENT */
 	{ FALSE, NULL,                 N_("Route server"),                    NULL }, /* GST_ROLE_ROUTE_SERVER */
 	{ TRUE,  NULL,                 N_("RPC mapper"),                      NULL }, /* GST_ROLE_RPC_MAPPER */
 	{ TRUE,  NULL,                 N_("SNMP server"),                     NULL }, /* GST_ROLE_SNMP_SERVER */
 	{ TRUE,  NULL,                 N_("Terminal server client"),          NULL }, /* GST_ROLE_LTSP_CLIENT */
 	{ FALSE, "gnome-mixer",        N_("Audio settings management"),       NULL }, /* GST_ROLE_AUDIO_MANAGEMENT */
 	{ FALSE, "disks",              N_("Volumes mounter"),                 N_("Mounts your volumes automatically") },        /* GST_ROLE_AUTOMOUNTER */
-	{ FALSE, NULL,                 N_("Infrared port management"),        NULL }, /* GST_ROLE_INFRARED_MANAGEMENT */
+	{ FALSE, "preferences-desktop-peripherals", N_("Infrared port management"),        NULL }, /* GST_ROLE_INFRARED_MANAGEMENT */
 	{ TRUE,  "access",             N_("Braille display management"),      NULL }, /* GST_ROLE_BRAILLE_DISPLAY_MANAGEMENT */
-	{ FALSE, "stock_bluetooth",    N_("Bluetooth device management"),     NULL }, /* GST_ROLE_BLUETOOTH_MANAGEMENT */
+	{ FALSE, "bluetooth",          N_("Bluetooth device management"),     NULL }, /* GST_ROLE_BLUETOOTH_MANAGEMENT */
 	{ FALSE, "drive-harddisk",     N_("Hard disk tuning"),                NULL }, /* GST_ROLE_HDD_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Hotkeys management"),              NULL }, /* GST_ROLE_HOTKEYS_MANAGEMENT */
-	{ FALSE, NULL,                 N_("Power management"),                NULL }, /* GST_ROLE_POWER_MANAGEMENT */
+	{ FALSE, "battery",            N_("Power management"),                NULL }, /* GST_ROLE_POWER_MANAGEMENT */
 	{ TRUE,  NULL,                 N_("Logical volume management"),       NULL }, /* GST_ROLE_LVM_MANAGEMENT */
 	{ TRUE,  NULL,                 N_("Cluster management tool"),         NULL }, /* GST_ROLE_CLUSTER_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Fax settings management"),         NULL }, /* GST_ROLE_FAX_MANAGEMENT */
 	{ TRUE,  "drive-harddisk",     N_("RAID disks management"),           NULL }, /* GST_ROLE_RAID_MANAGEMENT */
-	{ FALSE, NULL,                 N_("Graphic tablets management"),      NULL }, /* GST_ROLE_GRAPHIC_TABLETS_MANAGEMENT */
+	{ FALSE, "input-tablet",       N_("Graphic tablets management"),      NULL }, /* GST_ROLE_GRAPHIC_TABLETS_MANAGEMENT */
 	{ FALSE, NULL,                 N_("CPU Frequency manager"),           NULL }, /* GST_ROLE_CPUFREQ_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Eagle USB ADSL modems manager"),   NULL }, /* GST_ROLE_EAGLE_USB_MODEMS_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Serial port settings management"), NULL }, /* GST_ROLE_SERIAL_PORTS_MANAGEMENT */
-	{ FALSE, NULL,                 N_("ISDN modems manager"),             NULL }, /* GST_ROLE_ISDN_MANAGEMENT */
+	{ FALSE, "modem",              N_("ISDN modems manager"),             NULL }, /* GST_ROLE_ISDN_MANAGEMENT */
 	{ FALSE, NULL,                 N_("Telstra Bigpond Cable Network client"), NULL }, /* GST_ROLE_TELSTRA_BIGPOND_NETWORK_CLIENT */
 	{ FALSE, NULL,                 N_("Hardware monitor"),                NULL }, /* GST_ROLE_HARDWARE_MONITORING */
-	{ FALSE, NULL,                 N_("System monitor"),                  NULL }, /* GST_ROLE_SYSTEM_MONITORING */
-	{ FALSE, NULL,                 N_("Virtual Machine management"),      NULL }, /* GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT */
+	{ FALSE, "utilities-system-monitor", N_("System monitor"),            NULL }, /* GST_ROLE_SYSTEM_MONITORING */
+	{ FALSE, "computer",           N_("Virtual Machine management"),      NULL }, /* GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT */
 	{ FALSE }
 };
 
