@@ -29,6 +29,7 @@
 enum {
 	COL_ACTIVE,
 	COL_DESC,
+	COL_TOOLTIP,
 	COL_IMAGE,
 	COL_DANGEROUS,
 	COL_OBJECT,
@@ -41,7 +42,6 @@ enum {
 };
 
 void			table_create				(void);
-void			table_populate				(xmlNodePtr, gchar*);
 void                    table_empty                             (void);
 
 #endif /* _TABLE_H */
