@@ -36,9 +36,17 @@ void      on_share_nfs_delete_clicked         (GtkWidget*, gpointer);
 void      on_share_nfs_add_clicked            (GtkWidget*, gpointer);
 void      on_share_nfs_host_type_changed      (GtkWidget*, gpointer);
 void      on_share_smb_settings_clicked       (GtkWidget*, gpointer);
+void      on_dialog_validate                  (GtkWidget*, gpointer);
+void      on_shared_folder_changed            (GtkWidget *widget, gpointer data);
+void      on_share_smb_name_modified          (GtkWidget *widget, gpointer data);
 
 void      on_shares_dragged_folder            (GtkWidget *widget, GdkDragContext *context,
 					       gint x, gint y, GtkSelectionData *selection_data,
 					       guint info, guint time, gpointer gdata);
 
+void      on_is_wins_toggled                  (GtkWidget *widget, gpointer data);
+gboolean  on_workgroup_focus_out              (GtkWidget *widget, GdkEvent *event, gpointer data);
+gboolean  on_wins_server_focus_out            (GtkWidget *widget, GdkEvent *event, gpointer data);
+
+
 #endif /* __CALLBACKS_H */
