@@ -92,7 +92,6 @@ gst_time_tool_class_init (GstTimeToolClass *class)
 static void
 get_ntp_service (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 	GObject *service;
 	OobsList *list;
 	OobsListIter iter;
@@ -117,7 +116,6 @@ get_ntp_service (GstTimeTool *tool)
 static void
 gst_time_tool_init (GstTimeTool *tool)
 {
-	OobsList *list;
 	DBusError error;
 	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 
@@ -195,7 +193,6 @@ inhibit_screensaver (GstTimeTool *tool,
 static gboolean
 on_apply_timeout (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 	guint year, month, day, hour, minute, second;
 
 	gtk_calendar_get_date (GTK_CALENDAR (tool->calendar), &year, &month, &day);
@@ -348,10 +345,8 @@ init_timezone (GstTimeTool *time_tool)
 {
 	GstTool *tool = GST_TOOL (time_tool);
 	GtkWidget *w;
-	GtkCellRenderer *cell;
 	GPtrArray *locs;
-	GList *combo_locs = NULL;
-	int i;
+	guint i;
 
 	time_tool->tzmap = e_tz_map_new (tool);
 	g_return_if_fail (time_tool->tzmap != NULL);
@@ -361,14 +356,11 @@ init_timezone (GstTimeTool *time_tool)
 	gtk_widget_show (GTK_WIDGET (time_tool->tzmap->map));
 
 	w = gst_dialog_get_widget (tool->main_dialog, "location_combo");
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), cell, "text", 0, NULL);
 	locs = tz_get_locations (e_tz_map_get_tz_db (time_tool->tzmap));
 
 	for (i = 0; i < locs->len; i++)
-		gtk_combo_box_append_text (GTK_COMBO_BOX (w),
-					   tz_location_get_zone (g_ptr_array_index (locs, i)));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (w),
+		                                tz_location_get_zone (g_ptr_array_index (locs, i)));
 
 	time_tool->timezone_dialog = gst_dialog_get_widget (tool->main_dialog, "time_zone_window");
 }
@@ -466,11 +458,11 @@ on_option_changed (GtkWidget   *combo,
 	container = gst_dialog_get_widget (GST_TOOL (time_tool)->main_dialog, "configuration_container");
 
 	/* remove the child */
-	if (GTK_BIN (container)->child)
-		gtk_container_remove (GTK_CONTAINER (container), GTK_BIN (container)->child);
+	if (gtk_bin_get_child (GTK_BIN (container)))
+		gtk_container_remove (GTK_CONTAINER (container), gtk_bin_get_child (GTK_BIN (container)));
 
 	gtk_container_add (GTK_CONTAINER (container), widget);
-	gtk_widget_show_all (container);
+	gtk_widget_show (container);
 }
 
 static void
@@ -486,7 +478,7 @@ add_option (GstTool      *tool,
 	toplevel = gtk_widget_get_toplevel (w);
 
 	g_object_ref (w);
-	gtk_container_remove (GTK_CONTAINER (w->parent), w);
+	gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (w)), w);
 	gtk_widget_destroy (toplevel);
 
 	gtk_list_store_append (store, &iter);
@@ -542,7 +534,6 @@ gst_time_tool_constructor (GType                  type,
 {
 	GObject *object;
 	GstTimeTool *time_tool;
-	GtkWidget *widget;
 
 	object = (* G_OBJECT_CLASS (gst_time_tool_parent_class)->constructor) (type,
 									       n_construct_properties,
@@ -575,7 +566,6 @@ static void
 gst_time_tool_finalize (GObject *object)
 {
 	GstTimeTool *tool = GST_TIME_TOOL (object);
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (object);
 
 	/* FIXME: missing things to free */
 	g_object_unref (tool->time_config);
@@ -586,7 +576,6 @@ gst_time_tool_finalize (GObject *object)
 static void
 update_servers_list (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv;
 	OobsList *list;
 	OobsListIter iter;
 	GObject *server;
@@ -755,9 +744,7 @@ gst_time_tool_run_timezone_dialog (GstTimeTool *time_tool)
 	GtkWidget *label;
 	const gchar *timezone;
 	gchar *tz_name = NULL;
-	gchar *old_tz_name = NULL;
 	TzLocation *tz_location;
-	gint correction;
 
 	tool  = GST_TOOL (time_tool);
 	label = gst_dialog_get_widget (tool->main_dialog, "tzlabel");
@@ -770,9 +757,9 @@ gst_time_tool_run_timezone_dialog (GstTimeTool *time_tool)
 
 	gst_dialog_add_edit_dialog (tool->main_dialog, time_tool->timezone_dialog);
 
-	gtk_widget_show_all (time_tool->timezone_dialog);
+	gtk_widget_show (time_tool->timezone_dialog);
 	gtk_dialog_run (GTK_DIALOG (time_tool->timezone_dialog));
-	gtk_widget_hide_all (time_tool->timezone_dialog);
+	gtk_widget_hide (time_tool->timezone_dialog);
 
 	gst_dialog_remove_edit_dialog (tool->main_dialog, time_tool->timezone_dialog);
 
