@@ -24,6 +24,7 @@
 #include <config.h>
 #include "gst.h"
 #include <glib/gi18n.h>
+#include <oobs/oobs-defines.h>
 
 #include <string.h>
 #include <ctype.h>
@@ -91,8 +92,7 @@ group_delete (GtkTreeModel *model, GtkTreePath *path)
 	GtkTreeIter iter;
 	OobsGroupsConfig *config;
 	OobsGroup *group;
-	OobsList *groups_list;
-	OobsListIter *list_iter;
+	OobsResult result;
 	gboolean retval = FALSE;
 
 	if (!gtk_tree_model_get_iter (model, &iter, path))
@@ -100,81 +100,51 @@ group_delete (GtkTreeModel *model, GtkTreePath *path)
 
 	gtk_tree_model_get (model, &iter,
 			    COL_GROUP_OBJECT, &group,
-			    COL_GROUP_ITER, &list_iter,
 			    -1);
 
 	if (check_group_delete (group)) {
 		config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
-		groups_list = oobs_groups_config_get_groups (config);
-		oobs_list_remove (groups_list, list_iter);
-
-		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
-		retval = TRUE;
+		result = oobs_groups_config_delete_group (config, group);
+		if (result == OOBS_RESULT_OK) {
+			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+			retval = TRUE;
+		}
+		else {
+			gst_tool_commit_error (tool, result);
+			retval = FALSE;
+		}
 	}
 
 	g_object_unref (group);
-	oobs_list_iter_free (list_iter);
 
 	return retval;
 
 }
 
-gid_t
-group_settings_find_new_gid (void)
-{
-	OobsGroupsConfig *config;
-	OobsList *list;
-	OobsListIter list_iter;
-	GObject *group;
-	gboolean valid;
-	gid_t new_gid, gid, gid_min, gid_max;
-
-	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
-	list = oobs_groups_config_get_groups (config);
-	valid = oobs_list_get_iter_first (list, &list_iter);
-
-	gid_min = GST_USERS_TOOL (tool)->minimum_gid;
-	gid_max = GST_USERS_TOOL (tool)->maximum_gid;
-
-	new_gid = gid_min - 1;
-
-	while (valid) {
-		group = oobs_list_get (list, &list_iter);
-		gid = oobs_group_get_gid (OOBS_GROUP (group));
-		g_object_unref (group);
-
-		if (gid <= gid_max && gid >= gid_min && new_gid < gid)
-			new_gid = gid;
-
-		valid = oobs_list_iter_next (list, &list_iter);
-	}
-
-	new_gid++;
-
-	return new_gid;
-}
-
 GtkWidget*
 group_settings_dialog_new (OobsGroup *group)
 {
+	OobsGroupsConfig *config;
 	GtkWidget *dialog, *widget;
 	const gchar *name;
 	gchar *title;
+	gid_t gid;
+
+	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
 
 	dialog = gst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	name = oobs_group_get_name (group);
 
 	/* Set this before setting the GID so that it's not rejected */
 	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
-	gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget), 0, G_MAXINT32);
+	gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget), 0, OOBS_MAX_GID);
 
 	if (!name) {
 		g_object_set_data (G_OBJECT (dialog), "is_new", GINT_TO_POINTER (TRUE));
 		gtk_window_set_title (GTK_WINDOW (dialog), _("New group"));
 
 		widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget),
-					   group_settings_find_new_gid ());
+		gid = oobs_groups_config_find_free_gid (config, 0, 0);
 	} else {
 		g_object_set_data (G_OBJECT (dialog), "is_new", GINT_TO_POINTER (FALSE));
 
@@ -183,9 +153,11 @@ group_settings_dialog_new (OobsGroup *group)
 		g_free (title);
 
 		widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), oobs_group_get_gid (group));
+		gid = oobs_group_get_gid (group);
 	}
 
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), gid);
+
 	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_name");
 	gtk_entry_set_text (GTK_ENTRY (widget), (name) ? name : "");
 	gtk_widget_set_sensitive (widget, (name == NULL));
@@ -207,59 +179,6 @@ group_settings_dialog_group_is_new (void)
 	return is_new;
 }
 
-static gboolean
-is_group_root (OobsGroup *group)
-{
-	const gchar *name = oobs_group_get_name (group);
-
-	if (!name)
-		return FALSE;
-
-	return (strcmp (name, "root") == 0);
-}
-
-/* Get the OobsGroup corresponding to a name, or NULL if it does not exist.
- * Don't forget to unref the group when valid. */
-OobsGroup *
-group_settings_get_group_from_name (const gchar *name)
-{
-	OobsGroupsConfig *config;
-	OobsList *groups_list;
-	OobsListIter iter;
-	OobsGroup *group;
-	gboolean valid;
-	const gchar *group_name;
-
-	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
-	groups_list = oobs_groups_config_get_groups (config);
-	valid = oobs_list_get_iter_first (groups_list, &iter);
-
-	while (valid) {
-		group = OOBS_GROUP (oobs_list_get (groups_list, &iter));
-		group_name = oobs_group_get_name (group);
-
-		if (group_name && strcmp (name, group_name) == 0)
-			return group;
-
-		valid = oobs_list_iter_next (groups_list, &iter);
-	}
-
-	return NULL;
-}
-
-gboolean
-group_settings_group_exists (const gchar *name)
-{
-	OobsGroup *group = group_settings_get_group_from_name (name);
-
-	if (group) {
-		g_object_unref (group);
-		return TRUE;
-	}
-	else
-		return FALSE;
-}
-
 /* FIXME: this function is duplicated in user-settings.c */
 static gboolean
 is_valid_name (const gchar *name)
@@ -284,17 +203,20 @@ is_valid_name (const gchar *name)
 static void
 check_name (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
+	OobsGroupsConfig *config;
 	OobsGroup *group = OOBS_GROUP (data);
 	GtkWidget *widget;
 	const gchar *name;
 
+	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
+
 	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_name");
 	name = gtk_entry_get_text (GTK_ENTRY (widget));
 
 	if (strlen (name) < 1) {
 		*primary_text = g_strdup (_("Group name is empty"));
 		*secondary_text = g_strdup (_("A group name must be specified."));
-	} else if (is_group_root (group) && strcmp (name, "root") != 0) {
+	} else if (oobs_group_is_root (group) && strcmp (name, "root") != 0) {
 		*primary_text = g_strdup (_("Group name of the administrator group user should not be modified"));
 		*secondary_text = g_strdup (_("This would leave the system unusable."));
 	} else if (!is_valid_name (name)) {
@@ -302,7 +224,8 @@ check_name (gchar **primary_text, gchar **secondary_text, gpointer data)
 		*secondary_text = g_strdup (_("Please set a valid group name consisting of "
 					      "a lower case letter followed by lower case "
 					      "letters and numbers."));
-	} else if (group_settings_dialog_group_is_new () && group_settings_group_exists (name)) {
+	} else if (group_settings_dialog_group_is_new ()
+	           && oobs_groups_config_is_name_used (config, name)) {
 		*primary_text = g_strdup_printf (_("Group \"%s\" already exists"), name);
 		*secondary_text = g_strdup (_("Please choose a different group name."));
 	}
@@ -312,16 +235,39 @@ static void
 check_gid (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
 	OobsGroup *group = OOBS_GROUP (data);
+	OobsGroupsConfig *config;
+	OobsGroup *gid_group;
 	GtkWidget *widget;
-	gint gid;
+	gid_t gid;
+	gboolean new;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
-	gid = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
+	/* we know the value is positive because the range is limited */
+	gid = (unsigned) gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
+	new = group_settings_dialog_group_is_new ();
 
-	if (is_group_root (group) && gid != 0) {
+	/* don't warn if nothing has changed */
+	if (!new && gid == oobs_group_get_gid (group))
+		return;
+
+	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
+	gid_group = oobs_groups_config_get_from_gid (config, gid);
+
+	if (oobs_group_is_root (group) && gid != 0) {
 		*primary_text = g_strdup (_("Group ID of the Administrator account should not be modified"));
 		*secondary_text = g_strdup (_("This would leave the system unusable."));
 	}
+	else if (gid_group) { /* check that GID is free */
+		*primary_text   = g_strdup_printf (_("Group ID %d is already used by group \"%s\""),
+		                                   gid, oobs_group_get_name (gid_group));
+		if (new)
+			*secondary_text = g_strdup (_("Please choose a different numeric identifier for the new group."));
+		else
+			*secondary_text = g_strdup_printf (_("Please choose a different numeric identifier for group \"%s\"."),
+			                                   oobs_group_get_name (group));
+
+		g_object_unref (gid_group);
+	}
 }
 
 gint
