@@ -35,6 +35,8 @@
 
 extern GstTool *tool;
 
+static GtkListStore *privileges_model = NULL;
+
 enum {
 	COL_MEMBER,
 	COL_DESCRIPTION,
@@ -100,20 +102,13 @@ privilege_search (const gchar *group)
 static void
 on_user_privilege_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
-	GtkTreeModel *model, *child_model;
 	GtkTreePath  *path  = gtk_tree_path_new_from_string (path_str);
-	GtkTreeIter   iter, child_iter;
+	GtkTreeIter   iter;
 	OobsGroup    *group;
 	gboolean      value;
 
-	model = (GtkTreeModel*) data;
-
-	if (gtk_tree_model_get_iter (model, &iter, path)) {
-		child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model),
-								  &child_iter, &iter);
-
-		gtk_tree_model_get (child_model, &child_iter,
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (privileges_model), &iter, path)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (privileges_model), &iter,
 		                    COL_MEMBER, &value,
 		                    COL_GROUP, &group, -1);
 
@@ -121,7 +116,7 @@ on_user_privilege_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointe
 		 * possibly showing a warning/error dialog */
 		if (!value || strcmp (oobs_group_get_name (group), ADMIN_GROUP) != 0
 		           || user_settings_check_revoke_admin_rights ())
-			gtk_list_store_set (GTK_LIST_STORE (child_model), &child_iter, COL_MEMBER, !value, -1);
+			gtk_list_store_set (privileges_model, &iter, COL_MEMBER, !value, -1);
 
 		g_object_unref (group);
 	}
@@ -129,43 +124,20 @@ on_user_privilege_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointe
 	gtk_tree_path_free (path);
 }
 
-static gboolean
-privileges_table_visible_func (GtkTreeModel *model,
-			       GtkTreeIter  *iter,
-			       gpointer      data)
-{
-	gboolean visible;
-	gchar *str;
-
-	gtk_tree_model_get (model, iter,
-			    COL_DESCRIPTION, &str,
-			    -1);
-	visible = (str != NULL);
-	g_free (str);
-
-	return visible;
-}
-
 void
 create_user_privileges_table (void)
 {
 	GtkWidget *list;
-	GtkTreeModel *model, *filter_model;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
 	list = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
 
-	model = GTK_TREE_MODEL (gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_OBJECT));
-	filter_model = gtk_tree_model_filter_new (model, NULL);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (list), filter_model);
-	g_object_unref (filter_model);
-	g_object_unref (model);
+	privileges_model = gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_OBJECT);
+	gtk_tree_view_set_model (GTK_TREE_VIEW (list), GTK_TREE_MODEL (privileges_model));
+	g_object_unref (privileges_model);
 
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), COL_DESCRIPTION, GTK_SORT_ASCENDING);
-	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (filter_model),
-						privileges_table_visible_func,
-						NULL, NULL);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (privileges_model), COL_DESCRIPTION, GTK_SORT_ASCENDING);
 
 	column = gtk_tree_view_column_new ();
 
@@ -176,7 +148,7 @@ create_user_privileges_table (void)
 					     "active", COL_MEMBER,
 					     NULL);
 	g_signal_connect (G_OBJECT (renderer), "toggled",
-			  G_CALLBACK (on_user_privilege_toggled), filter_model);
+			  G_CALLBACK (on_user_privilege_toggled), NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_end (column, renderer, TRUE);
@@ -193,54 +165,40 @@ void
 privileges_table_add_group (OobsGroup *group)
 {
 	const PrivilegeDescription *p;
-	GtkWidget *table;
-	GtkTreeModel *model;
-	GtkListStore *store;
-	GtkTreeIter iter;
 
 	p = privilege_search (oobs_group_get_name (group));
 	if (p == NULL) /* Ignore groups that don't match a privilege */
 		return;
 
-	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	store = GTK_LIST_STORE (gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model)));
-
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter,
-			    COL_MEMBER, FALSE,
-			    COL_DESCRIPTION, (p) ? _(p->privilege) : NULL,
-			    COL_GROUP, group,
-			    -1);
+	gtk_list_store_insert_with_values (privileges_model, NULL, G_MAXINT,
+	                                   COL_MEMBER, FALSE,
+	                                   COL_DESCRIPTION, (p) ? _(p->privilege) : NULL,
+	                                   COL_GROUP, group,
+	                                   -1);
 }
 
 void
 privileges_table_set_from_user (OobsUser *user)
 {
-	GtkWidget *table;
-	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	gboolean valid;
 	OobsGroup *group;
 	GList *users;
 
-	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-	valid = gtk_tree_model_get_iter_first (child_model, &iter);
+	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (privileges_model), &iter);
 
 	while (valid) {
-		gtk_tree_model_get (child_model, &iter,
+		gtk_tree_model_get (GTK_TREE_MODEL (privileges_model), &iter,
 				    COL_GROUP, &group,
 				    -1);
 
 		users = oobs_group_get_users (group);
-		gtk_list_store_set (GTK_LIST_STORE (child_model), &iter,
+		gtk_list_store_set (privileges_model, &iter,
 				    COL_MEMBER, (g_list_find (users, user) != NULL),
 				    -1);
 		g_list_free (users);
 		g_object_unref (group);
-		valid = gtk_tree_model_iter_next (child_model, &iter);
+		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (privileges_model), &iter);
 	}
 }
 
@@ -270,47 +228,37 @@ find_group_in_profile (OobsGroup      *group,
 void
 privileges_table_set_from_profile (GstUserProfile *profile)
 {
-	GtkWidget *table;
-	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	gboolean valid;
 	OobsGroup *group;
 
-	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-	valid = gtk_tree_model_get_iter_first (child_model, &iter);
+	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (privileges_model), &iter);
 
 	while (valid) {
-		gtk_tree_model_get (child_model, &iter,
+		gtk_tree_model_get (GTK_TREE_MODEL (privileges_model), &iter,
 				    COL_GROUP, &group,
 				    -1);
 
-		gtk_list_store_set (GTK_LIST_STORE (child_model), &iter,
+		gtk_list_store_set (privileges_model, &iter,
 				    COL_MEMBER, find_group_in_profile (group, profile),
 				    -1);
 
 		g_object_unref (group);
-		valid = gtk_tree_model_iter_next (child_model, &iter);
+		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (privileges_model), &iter);
 	}
 }
 
 void
 privileges_table_save (OobsUser *user)
 {
-	GtkWidget *table;
-	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	OobsGroup *group;
 	gboolean valid, member;
 
-	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-	valid = gtk_tree_model_get_iter_first (child_model, &iter);
+	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (privileges_model), &iter);
 
 	while (valid) {
-		gtk_tree_model_get (child_model, &iter,
+		gtk_tree_model_get (GTK_TREE_MODEL (privileges_model), &iter,
 				    COL_GROUP, &group,
 				    COL_MEMBER, &member,
 				    -1);
@@ -319,19 +267,12 @@ privileges_table_save (OobsUser *user)
 		else
 			oobs_group_remove_user (group, user);
 
-		valid = gtk_tree_model_iter_next (child_model, &iter);
+		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (privileges_model), &iter);
 	}
 }
 
 void
 privileges_table_clear (void)
 {
-	GtkWidget *table;
-	GtkTreeModel *model, *child_model;
-
-	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
-
-	gtk_list_store_clear (GTK_LIST_STORE (child_model));
+	gtk_list_store_clear (privileges_model);
 }
