@@ -106,7 +106,7 @@ setup_shells_combo (GstUsersTool *tool)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
 	g_object_unref (model);
 
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (combo), 0);
 }
 
 void
@@ -178,10 +178,14 @@ table_populate_profiles (GstUsersTool *tool,
 		                                                     profile->name);
 		label = gtk_label_new (profile->description);
 		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_FILL);
 		gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 		gtk_misc_set_padding (GTK_MISC (label), 16, 0);
 		gtk_label_set_attributes (GTK_LABEL (label), attributes);
 
+		/* To force a minimum size for the dialog, set a somewhat arbitrary length */
+		gtk_label_set_width_chars (GTK_LABEL (label), 50);
+
 		gtk_table_attach_defaults (GTK_TABLE (table),
 		                           radio, 0, ncols,
 		                           nrows + i, nrows + i + 1);
@@ -209,58 +213,3 @@ create_tables (GstUsersTool *tool)
 	setup_groups_combo ();
 	setup_shells_combo (tool);
 }
-
-static GtkWidget*
-get_table (gint table)
-{
-	switch (table) {
-	case TABLE_USERS:
-		return gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "users_table");
-	case TABLE_GROUPS:
-		return gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "groups_table");
-	default:
-		g_assert_not_reached ();
-	}
-}
-
-GList*
-table_get_row_references (gint table, GtkTreeModel **model)
-{
-	GtkTreeSelection *selection;
-	GtkTreeModel *table_model;
-	GtkTreePath *child_path;
-	GList *paths, *elem, *list = NULL;
-
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (get_table (table)));
-	paths = elem = gtk_tree_selection_get_selected_rows (selection, &table_model);
-	if (table == TABLE_USERS)
-		*model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (table_model));
-	else
-		*model = table_model;
-
-	if (!paths)
-		return NULL;
-
-	if (table == TABLE_USERS) {
-		while (elem) {
-			child_path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (table_model),
-			                                                               (GtkTreePath *) elem->data);
-
-			list = g_list_prepend (list, gtk_tree_row_reference_new (*model, child_path));
-			gtk_tree_path_free (child_path);
-			elem = elem->next;
-		}
-	}
-	else {
-		while (elem) {
-			list = g_list_prepend (list, gtk_tree_row_reference_new (*model, (GtkTreePath *) elem->data));
-			elem = elem->next;
-		}
-	}
-
-	list = g_list_reverse (list);
-	g_list_foreach (paths, (GFunc) gtk_tree_path_free, NULL);
-	g_list_free (paths);
-
-	return list;
-}
