@@ -173,6 +173,10 @@ user_delete (GtkTreeModel *model, GtkTreePath *path)
 		config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
 		result = oobs_users_config_delete_user (config, user);
 		if (result == OOBS_RESULT_OK) {
+			/* Take into account the possible deletion of user's main group.
+			 * If we update groups here, the 'changed' signal will be blocked, and
+			 * if it happens after 2 seconds, it will trigger a confirmation dialog. */
+			g_idle_add (gst_users_tool_update_groups_async, tool);
 			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 			retval = TRUE;
 		}
@@ -319,7 +323,8 @@ user_settings_show (OobsUser *user)
 	face_image = gst_dialog_get_widget (tool->main_dialog, "user_settings_face");
 	face = user_settings_get_user_face (user, 60);
 	gtk_image_set_from_pixbuf (GTK_IMAGE (face_image), face);
-	g_object_unref (face);
+	if (face)
+		g_object_unref (face);
 
 	profile_label = gst_dialog_get_widget (tool->main_dialog, "user_settings_profile");
 	profile_button = gst_dialog_get_widget (tool->main_dialog, "edit_user_profile_button");
@@ -896,32 +901,38 @@ on_user_new_name_changed (GtkEditable *user_name, gpointer user_data)
 
 	used_login = oobs_users_config_is_login_used (config, item1->str);
 	if (nwords2 > 0 && !used_login && !isdigit(item1->str[0]))
-		gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), item1->str);
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+		                                item1->str);
 
 	/* if there's only one word, would be the same as item1 */
 	if (nwords2 > 1) {
 		/* add other items */
 		used_login = oobs_users_config_is_login_used (config, item2->str);
 		if (!used_login && !isdigit(item2->str[0]))
-			gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), item2->str);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+			                                item2->str);
 
 		used_login = oobs_users_config_is_login_used (config, item3->str);
 		if (!used_login && !isdigit(item3->str[0]))
-			gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), item3->str);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+			                                item3->str);
 
 		used_login = oobs_users_config_is_login_used (config, item4->str);
 		if (!used_login && !isdigit(item4->str[0]))
-			gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), item4->str);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+			                                item4->str);
 
 		/* add the last word */
 		used_login = oobs_users_config_is_login_used (config, last_word->str);
 		if (!used_login && !isdigit(last_word->str[0]))
-			gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), last_word->str);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+			                                last_word->str);
 
 		/* ...and the first one */
 		used_login = oobs_users_config_is_login_used (config, first_word->str);
 		if (!used_login && !isdigit(first_word->str[0]))
-			gtk_combo_box_append_text (GTK_COMBO_BOX (user_login), first_word->str);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (user_login),
+			                                first_word->str);
 	}
 
 
@@ -954,10 +965,10 @@ on_user_new_login_changed (GtkComboBox *login_combo, gpointer user_data)
 	gboolean empty_login;
 	gboolean valid_login;
 	gboolean valid_name;
-	char *login;
-	char *c;
+	const char *login;
+	const char *c;
 
-	login = gtk_combo_box_get_active_text (login_combo);
+	login = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (login_combo))));
 	login_entry = gtk_bin_get_child (GTK_BIN (login_combo));
 	validate_button = gst_dialog_get_widget (tool->main_dialog, "user_new_validate_button");
 	notice_image = gst_dialog_get_widget (tool->main_dialog, "user_new_notice_image");
@@ -1080,7 +1091,7 @@ on_user_new (GtkButton *button, gpointer user_data)
 	/* Create user with base data entered by the user.
 	   Main group will be automatically managed by the backends,
 	   following the system configuration. */
-	login = gtk_combo_box_get_active_text (GTK_COMBO_BOX (user_login));
+	login = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (user_login))));
 	fullname = gtk_entry_get_text (GTK_ENTRY (user_name));
 	encrypt = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (encrypted_home));
 	user = oobs_user_new (login);
@@ -1122,6 +1133,11 @@ on_user_new (GtkButton *button, gpointer user_data)
 		users_table_select_path (user_path);
 		gtk_tree_path_free (user_path);
 
+		/* Take into account possibly new main group for user.
+		 * If we update groups here, the 'changed' signal will be blocked,
+		 * and if it happens after 2 seconds, it will trigger a confirmation dialog. */
+		g_idle_add (gst_users_tool_update_groups_async, tool);
+
 		/* Finally, run the password edit dialog.
 		 * User can hit cancel, leaving the account disabled */
 		on_edit_user_passwd (NULL, NULL);
@@ -1277,14 +1293,14 @@ on_edit_user_profile (GtkButton *button, gpointer user_data)
 
 	if (profile) {
 		radio = g_hash_table_lookup (radios, profile->name);
-		gtk_widget_set_sensitive (custom_radio, FALSE);
+		gtk_widget_hide (custom_radio);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
-		gtk_widget_set_sensitive (custom_label, FALSE);
+		gtk_widget_hide (custom_label);
 	}
 	else {
-		gtk_widget_set_sensitive (custom_radio, TRUE);
+		gtk_widget_show (custom_radio);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (custom_radio), TRUE);
-		gtk_widget_set_sensitive (custom_label, FALSE);
+		gtk_widget_show (custom_label);
 	}
 
 	response = run_edit_dialog (GTK_DIALOG (user_profile_dialog),
@@ -1333,12 +1349,18 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	GtkWidget *user_advanced_dialog;
 	GtkWidget *face_image;
 	GtkWidget *name_label;
-	GtkWidget *uid_notice;
+	GtkWidget *active_notice;
+	GtkWidget *active_label;
+	GtkWidget *uid_entry;
+	GtkWidget *locked_checkbox;
+	GtkWidget *home_entry;
 	GtkWidget *widget;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	OobsUser *user;
 	OobsGroup *main_group;
+	gboolean password_disabled;
+	OobsGroup *no_passwd_login_group;
 	int response;
 
 	TestBattery battery[] = {
@@ -1372,30 +1394,53 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
 	set_entry_text (gtk_bin_get_child (GTK_BIN (widget)), oobs_user_get_shell (user));
 
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
-	set_entry_text (widget, oobs_user_get_home_directory (user));
+	home_entry = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
+	set_entry_text (home_entry, oobs_user_get_home_directory (user));
 
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), oobs_user_get_uid (user));
-
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_locked_account");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), oobs_user_get_password_disabled (user));
+	uid_entry = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (uid_entry), oobs_user_get_uid (user));
 
+	locked_checkbox = gst_dialog_get_widget (tool->main_dialog, "user_settings_locked_account");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (locked_checkbox),
+	                              oobs_user_get_password_disabled (user));
 
 	/* show a notice if the user is logged in */
-	uid_notice = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid_disabled");
+	active_notice = gst_dialog_get_widget (tool->main_dialog, "user_settings_active_notice");
+	active_label = gst_dialog_get_widget (tool->main_dialog, "user_settings_active_label");
 
 	if (oobs_user_is_root (user)) {
-		gtk_widget_set_sensitive (widget, FALSE);
-		gtk_widget_hide (uid_notice);
+		gtk_widget_set_sensitive (locked_checkbox, TRUE);
+		gtk_widget_set_sensitive (home_entry, TRUE);
+		gtk_widget_set_sensitive (uid_entry, FALSE);
+		gtk_label_set_text (GTK_LABEL (active_label),
+		                    _("You cannot change the user ID for the superuser account."));
+		gtk_widget_show (active_notice);
+	}
+	else if (oobs_self_config_is_user_self (OOBS_SELF_CONFIG (GST_USERS_TOOL (tool)->self_config), user)) {
+		gtk_widget_set_sensitive (locked_checkbox, FALSE);
+		gtk_widget_set_sensitive (home_entry, FALSE);
+		gtk_widget_set_sensitive (uid_entry, FALSE);
+		gtk_label_set_text (GTK_LABEL (active_label),
+                                    _("You cannot disable your own account, "
+		                      "nor change your own home directory or user ID. "
+		                      "Run this program from another user's session to edit these settings."));
+		gtk_widget_show (active_notice);
 	}
 	else if (oobs_user_get_active (user)) {
-		gtk_widget_set_sensitive (widget, FALSE);
-		gtk_widget_show (uid_notice);
+		gtk_widget_set_sensitive (locked_checkbox, FALSE);
+		gtk_widget_set_sensitive (home_entry, FALSE);
+		gtk_widget_set_sensitive (uid_entry, FALSE);
+		gtk_label_set_text (GTK_LABEL (active_label),
+				    _("You cannot change an account's home directory or user ID "
+		                      "while the user is logged in."));
+		gtk_widget_show (active_notice);
 	}
 	else {
-		gtk_widget_set_sensitive (widget, TRUE);
-		gtk_widget_hide (uid_notice);
+		gtk_widget_set_sensitive (locked_checkbox, TRUE);
+		gtk_widget_set_sensitive (home_entry, TRUE);
+		gtk_widget_set_sensitive (uid_entry, TRUE);
+
+		gtk_widget_hide (active_notice);
 	}
 
 	privileges_table_set_from_user (user);
@@ -1435,7 +1480,15 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	oobs_user_set_uid (user, gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget)));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_locked_account");
-	oobs_user_set_password_disabled (user, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)));
+	password_disabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+	oobs_user_set_password_disabled (user, password_disabled);
+	/* Leaving user in the password-less login group would still allow him to login,
+	 * which defeats the purpose of disabling account */
+	no_passwd_login_group =
+		oobs_groups_config_get_from_name (OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config),
+		                                  NO_PASSWD_LOGIN_GROUP);
+	if (password_disabled && no_passwd_login_group)
+		oobs_group_remove_user (no_passwd_login_group, user);
 
 	privileges_table_save (user);
 
@@ -1460,4 +1513,6 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	                       on_commit_finish, user);
 
 	g_object_unref (user);
+	if (no_passwd_login_group)
+		g_object_unref (no_passwd_login_group);
 }
