@@ -54,36 +54,34 @@ gst_users_tool_class_init (GstUsersToolClass *class)
 }
 
 static void
-on_option_changed (GConfClient *client,
-		    guint        conn_id,
-		    GConfEntry  *entry,
-		    gpointer     data)
+on_option_changed (GSettings  *settings,
+                   const char *key,
+                   gpointer    user_data)
 {
-	GstTool *tool = GST_TOOL (data);
-	GtkWidget *widget;
-	GtkTreeModel *model;
+	GstTool *tool = GST_TOOL (user_data);
 
-	GST_USERS_TOOL (tool)->showall = gst_conf_get_boolean (GST_TOOL (tool), "showall");
-	GST_USERS_TOOL (tool)->showroot = gst_conf_get_boolean (GST_TOOL (tool), "showroot");
+	GST_USERS_TOOL (tool)->showall = g_settings_get_boolean (settings, "showall");
+	GST_USERS_TOOL (tool)->showroot = g_settings_get_boolean (settings, "showroot");
 
-	widget = gst_dialog_get_widget (tool->main_dialog, "users_table");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
+	/* We need to reload the users table since unshown users aren't added */
+	gst_tool_update_gui (tool);
 }
 
 static void
 gst_users_tool_init (GstUsersTool *tool)
 {
 	tool->users_config = oobs_users_config_get ();
-	gst_tool_add_configuration_object (GST_TOOL (tool), tool->users_config);
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->users_config, TRUE);
 
 	tool->groups_config = oobs_groups_config_get ();
-	gst_tool_add_configuration_object (GST_TOOL (tool), tool->groups_config);
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->groups_config, TRUE);
 
 	tool->self_config = oobs_self_config_get ();
-	gst_tool_add_configuration_object (GST_TOOL (tool), tool->self_config);
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->self_config, TRUE);
 
 	tool->profiles = gst_user_profiles_get ();
+
+	tool->settings = g_settings_new ("org.gnome.system-tools.users");
 }
 
 static GObject*
@@ -92,20 +90,21 @@ gst_users_tool_constructor (GType                  type,
 			    GObjectConstructParam *construct_params)
 {
 	GObject *object;
-	GstTool *tool;
+	GstUsersTool *tool;
 
 	object = (* G_OBJECT_CLASS (gst_users_tool_parent_class)->constructor) (type,
 										n_construct_properties,
 										construct_params);
 
-	tool = GST_TOOL (object);
-	GST_USERS_TOOL (tool)->showall = gst_conf_get_boolean (GST_TOOL (tool), "showall");
-	GST_USERS_TOOL (tool)->showroot = gst_conf_get_boolean (GST_TOOL (tool), "showroot");
+	tool = GST_USERS_TOOL (object);
 
-	gst_conf_add_notify (GST_TOOL (tool), "showall",
-			     on_option_changed, tool);
-	gst_conf_add_notify (GST_TOOL (tool), "showroot",
-			     on_option_changed, tool);
+	g_signal_connect (tool->settings, "changed::showall",
+	                  (GCallback) on_option_changed, tool);
+	g_signal_connect (tool->settings, "changed::showroot",
+	                  (GCallback) on_option_changed, tool);
+
+	tool->showall = g_settings_get_boolean (tool->settings, "showall");
+	tool->showroot = g_settings_get_boolean (tool->settings, "showroot");
 
 	return object;
 }
@@ -116,8 +115,15 @@ gst_users_tool_finalize (GObject *object)
 	GstUsersTool *tool = GST_USERS_TOOL (object);
 
 	g_object_unref (tool->users_config);
+	g_object_unref (tool->self_config);
 	g_object_unref (tool->groups_config);
 	g_object_unref (tool->profiles);
+	g_object_unref (tool->settings);
+
+	/* Clear models to unreference OobsUsers and OobsGroups
+	 * to be sure they are finalized properly (passwords...) */
+	users_table_clear ();
+	groups_table_clear ();
 
 	(* G_OBJECT_CLASS (gst_users_tool_parent_class)->finalize) (object);
 }
@@ -127,24 +133,29 @@ update_users (GstUsersTool *tool)
 {
 	OobsList *list;
 	OobsListIter iter;
-	GObject *user;
+	OobsUser *user;
+	OobsUser *self;
+	GtkTreePath *path;
 	gboolean valid;
 
 	users_table_clear ();
 	list = oobs_users_config_get_users (OOBS_USERS_CONFIG (tool->users_config));
+	self = oobs_self_config_get_user (OOBS_SELF_CONFIG (tool->self_config));
 
 	valid = oobs_list_get_iter_first (list, &iter);
 
 	while (valid) {
-		user = oobs_list_get (list, &iter);
-		users_table_add_user (OOBS_USER (user));
-		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user));
+		user = OOBS_USER (oobs_list_get (list, &iter));
+		path = users_table_add_user (user);
+		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user), FALSE);
+
+		if (self == user)
+			users_table_select_path (path);
 
 		g_object_unref (user);
+		gtk_tree_path_free (path);
 		valid = oobs_list_iter_next (list, &iter);
 	}
-
-	users_table_select_first ();
 }
 
 static void
@@ -156,7 +167,9 @@ update_groups (GstUsersTool *tool)
 	gboolean valid;
 
 	groups_table_clear ();
+	groups_table_begin_insertions ();
 	privileges_table_clear ();
+
 	list = oobs_groups_config_get_groups (OOBS_GROUPS_CONFIG (tool->groups_config));
 
 	valid = oobs_list_get_iter_first (list, &iter);
@@ -164,7 +177,7 @@ update_groups (GstUsersTool *tool)
 	while (valid) {
 		group = oobs_list_get (list, &iter);
 		groups_table_add_group (OOBS_GROUP (group));
-		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (group));
+		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (group), FALSE);
 
 		/* update privileges table too */
 		privileges_table_add_group (OOBS_GROUP (group));
@@ -172,6 +185,8 @@ update_groups (GstUsersTool *tool)
 		g_object_unref (group);
 		valid = oobs_list_iter_next (list, &iter);
 	}
+
+	groups_table_end_insertions ();
 }
 
 static void
@@ -248,6 +263,18 @@ gst_users_tool_update_gui (GstTool *tool)
 	update_shells (GST_USERS_TOOL (tool));
 }
 
+/*
+ * Function called via g_idle_add() when we need to allow signals
+ * to be processed before updating.
+ */
+gboolean
+gst_users_tool_update_groups_async (gpointer data)
+{
+	update_groups (GST_USERS_TOOL (data));
+
+	return FALSE;
+}
+
 static void
 gst_users_tool_update_config (GstTool *tool)
 {
@@ -272,6 +299,6 @@ gst_users_tool_new (void)
 			     "name", "users",
 			     "title", _("Users Settings"),
 			     "icon", "config-users",
-	                     "lock-button", FALSE,
+	                     "show-lock-button", FALSE,
 			     NULL);
 }
